@@ -46,8 +46,10 @@ from datetime import datetime
 # XXX this should really go in its out package
 # see: https://bugzilla.mozilla.org/show_bug.cgi?id=603019
 
-platforms = ['linux', 
+platforms = ['linux',
+             'linux64',
              'win32',
+             'macosx',
              'macosx64']
 
 def platform():
@@ -63,6 +65,13 @@ def platform():
 
 ###
 
+class NotFoundException(Exception):
+  def __init__(self, message, url):
+    self.url = url
+    Exception.__init__(self, message)
+
+# TODO: fetch symbols from http://symbols.mozilla.org/firefox/ ?
+
 class GetLatestTinderbox(object):
 
   # class data
@@ -177,7 +186,10 @@ class GetLatestTinderbox(object):
       match = regex.match(href)
       if match:
         logs[match.group(1)] = '%s/%s' % (url.rstrip('/'), match.group(0))
-    return logs or None # None == failure
+    if logs:
+      return logs
+    else:
+      raise NotFoundException("No logs found", url)
 
 def main(args=sys.argv[1:]):
 
@@ -219,6 +231,9 @@ def main(args=sys.argv[1:]):
     parser.error('Specify your platform')
   if options.symbols and options.tests:
     parser.error("Can't specify --tests and --symbols")
+  if options.platform == 'macosx' and not options.debug:
+    # universal binary
+    parser.error("No more opt macosx builds; use the universal binary, macosx64")
 
   # instantiate class
   latest_tinderbox = GetLatestTinderbox(options.product, options.platform, options.debug)
@@ -236,9 +251,12 @@ def main(args=sys.argv[1:]):
   # print out all logs found
   if options.logs:
     logs = latest_tinderbox.logs(options.url)
-    for key in sorted(logs.keys()):
-      print '%s: %s' % (key, logs[key])
-    return
+    try:
+      for key in sorted(logs.keys()):
+        print '%s: %s' % (key, logs[key])
+      return
+    except NotFoundException, e:
+      import pdb; pdb.set_trace()
 
   # print out the URL for a specific log
   if options.log:
